{% extends "wheelcms_axle/base.html" %}


{% block base_main %}

<div class="row">
  <div class="col-lg-12">
    <h3>{{content.title}}</h3>
  </div>
</div>
<div class="row">
  <div class="col-lg-12">
    <table class="result-listing table table-hover">

    {% for n in contents %}
      {% with content=n.content spoke=n.content.spoke %}
    <tr class="state-{{result.state}}">
      <td>
        <span class="title"><img class="icon" src="{{spoke.full_icon_path}}"><a href="{{ n.get_absolute_url }}">{{ content.title }}</a></span>
        <span class="byline">{% if content.state == "private" %}<span class="badge badge-important">private</span>{%endif%} by {{spoke.owner_name}} &mdash; published {{content.publication}} &mdash; last modified {{content.modified}} {# &mdash; filed under foo, bar #}</span>
        <p>{{spoke.description|default:''|safe}}</p>
      </td>
    </tr>
      {% endwith %}
    {% endfor %}
    </table>
  </div>
</div>
{% endblock %}
