{% extends "wheelcms_axle/base.html" %}

{% block base_main %}
<div class="row">
  <div class="col-lg-12">
    <h1>{{content.title}}</h1>
  </div>
</div>
<div class="row">
  <div class="col-lg-12">
    {{content.body|safe}}
  </div>
</div>
{% endblock %}
